from setuptools import setup

setup(name='gauss_bi_distribution',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['gauss_bi_distribution'],
      zip_safe=False)
